# BIOPB java package

A simple utility package to simplify usage of biopb in Java.

 - Maven integration
 - Utility functions to serialize to/from imglib2 arrays.

## Use in your project

Include in your pom.xml
```xml
<dependencies>
    <dependency>
        <groupId>io.github.jiyuuchc</groupId>
        <artifactId>biopb</artifactId>
        <version>0.1.2</version>
    </dependency>
</dependencies>    
```
